// [[file:../arroyo-native-parser.org::*Library definition and exports for the Python library][Library definition and exports for the Python library:1]]
use pyo3::prelude::*;

pub mod parse;
pub mod export_html;
pub mod export_atom;
pub mod types;

#[pymodule]
fn arroyo_rs(py: Python, m: &PyModule) -> PyResult<()> {
    #[pyfn(m)]
    fn parse_file(path: String) -> PyResult<types::Document> {
        Ok(parse::parse_document(path)?)
    }

    #[pyfn(m)]
    fn htmlize_file(path: String, options: export_html::ExportOptions) -> PyResult<String> {
        Ok(export_html::htmlize_file(path, options)?)
    }

    #[pyfn(m)]
    fn atomize_file(path: String, options: export_html::ExportOptions) -> PyResult<String> {
        Ok(export_atom::atomize_file(path, options)?)
    }

    m.add_class::<types::Document>()?;
    m.add_class::<types::Heading>()?;
    m.add_class::<types::Keyword>()?;
    m.add_class::<types::Link>()?;
    m.add_class::<export_html::ExportOptions>()?;

    m.add("InvalidDocError", py.get_type::<types::InvalidDocError>())?;

    Ok(())
}
// Library definition and exports for the Python library:1 ends here
